==> gwt-mt-widgets-0.55.5.jar: de/knightsoftnet/mtwidgets/client/ui/widget/MonthBox.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.mtwidgets.client.ui.widget;

import de.knightsoftnet.mtwidgets.client.ui.widget.helper.MonthParser;
import de.knightsoftnet.mtwidgets.client.ui.widget.helper.MonthRenderer;

import com.google.gwt.event.logical.shared.ValueChangeEvent;

import elemental.client.Browser;

import java.util.Date;

/**
 * html5 month box for input.
 *
 * @author Manfred Tremmel
 *
 */
public class MonthBox extends AbstractMinMaxTextBox<Date> {

  /**
   * default constructor.
   */
  public MonthBox() {
    super(Browser.getDocument().createInputElement(), "month", MonthRenderer.instance(),
        MonthParser.instance(), null);
  }

  @Override
  public void setValue(final Date value, final boolean fireEvents) {
    final Date oldValue = getValue();
    getInputElement().setValue(MonthRenderer.instance().render(value));
    if (fireEvents) {
      ValueChangeEvent.fireIfNotEqual(this, oldValue, value);
    }
  }
}

==> gwt-mt-widgets-1.2.3.jar: de/knightsoftnet/mtwidgets/client/ui/widget/MonthBox.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.mtwidgets.client.ui.widget;

import de.knightsoftnet.mtwidgets.client.ui.widget.helper.MonthParser;
import de.knightsoftnet.mtwidgets.client.ui.widget.helper.MonthRenderer;

import com.google.gwt.event.logical.shared.ValueChangeEvent;

import elemental2.dom.DomGlobal;
import elemental2.dom.HTMLInputElement;

import java.util.Date;

/**
 * html5 month box for input.
 *
 * @author Manfred Tremmel
 *
 */
public class MonthBox extends AbstractMinMaxTextBox<Date> {

  /**
   * default constructor.
   */
  public MonthBox() {
    super((HTMLInputElement) DomGlobal.document.createElement("input"), "month",
        MonthRenderer.instance(), MonthParser.instance(), null);
  }

  @Override
  public void setValue(final Date value, final boolean fireEvents) {
    final Date oldValue = getValue();
    getInputElement().value = MonthRenderer.instance().render(value);
    if (fireEvents) {
      ValueChangeEvent.fireIfNotEqual(this, oldValue, value);
    }
  }
}
